@@ -3,26 +3,27 @@
 
 """Helper functions to perform augmentations on a :class:`PIL.Image.Image`.
 
-Augmentation that take an intensity value are normalized on a scale of 1-10,
-where 10 is the strongest and maximum value an augmentation
-function will accept.
+Augmentations that take an intensity value are normalized on a scale of 1-10,
+where 10 is the strongest and maximum value an augmentation function will accept.
 
 Adapted from
-`AugMix: A Simple Data Processing Method to Improve Robustness and Uncertainty <https://github.com/google-research/augmix/blob/master/augmentations.py>`_.
+`AugMix: A Simple Data Processing Method to Improve Robustness and Uncertainty
+<https://github.com/google-research/augmix/blob/master/augmentations.py>`_.
 
 Attributes:
-    AugmentationFn ((PIL.Image.Image, float) -> PIL.Image.Image): The type annotation for describing an
-        augmentation function.
+    AugmentationFn ((PIL.Image.Image, float) -> PIL.Image.Image):
+        The type annotation for describing an augmentation function.
 
-        Each augmentation takes a :class:`~PIL.Image.Image` and an intensity level on the range ``[0; 10]``,
+        Each augmentation takes a :class:`PIL.Image.Image` and an intensity level in the range ``[0, 10]``,
         and returns an augmented image.
 
     augmentation_sets (Dict[str, List[AugmentationFn]]): The collection of all augmentations.
         This dictionary has the following entries:
 
-        * ``augmentation_sets["safe"]`` contains augmentations that do not overlap with ImageNet-C/CIFAR10-C test sets.
-        * ``augmentation_sets["original"]`` contains augmentations that use the original implementations of
-          enhancing color, contrast, brightness, and sharpness.
+        * ``augmentation_sets["safe"]`` contains augmentations that do not overlap with
+            ImageNet-C/CIFAR10-C test sets.
+        * ``augmentation_sets["original"]`` contains augmentations that use the original
+            implementations of enhancing color, contrast, brightness, and sharpness.
         * ``augmentation_sets["all"]`` contains all augmentations.
 """
 from typing import Callable
@@ -33,25 +34,25 @@ from PIL import Image, ImageEnhance, ImageOps
 AugmentationFn = Callable[[Image.Image, float], Image.Image]
 
 __all__ = [
-    "AugmentationFn",
-    "autocontrast",
-    "equalize",
-    "posterize",
-    "rotate",
-    "solarize",
-    "shear_x",
-    "shear_y",
-    "translate_x",
-    "translate_y",
-    "color",
-    "color_original",
-    "contrast",
-    "contrast_original",
-    "brightness",
-    "brightness_original",
-    "sharpness",
-    "sharpness_original",
-    "augmentation_sets",
+    'AugmentationFn',
+    'autocontrast',
+    'equalize',
+    'posterize',
+    'rotate',
+    'solarize',
+    'shear_x',
+    'shear_y',
+    'translate_x',
+    'translate_y',
+    'color',
+    'color_original',
+    'contrast',
+    'contrast_original',
+    'brightness',
+    'brightness_original',
+    'sharpness',
+    'sharpness_original',
+    'augmentation_sets',
 ]
 
 
@@ -59,12 +60,12 @@ def _int_parameter(level: float, maxval: float):
     """Helper function to scale a value between ``0`` and ``maxval`` and return as an int.
 
     Args:
-      level (float): Level of the operation that will be between ``[0, 10]``.
-      maxval (float): Maximum value that the operation can have. This will be scaled to
-        ``level/10``.
+        level (float): Level of the operation that will be between ``[0, 10]``.
+        maxval (float): Maximum value that the operation can have. This will be scaled to
+            ``level/10``.
 
     Returns:
-      int: The result from scaling ``maxval`` according to ``level``.
+        int: The result from scaling ``maxval`` according to ``level``.
     """
     return int(level * maxval / 10)
 
@@ -73,11 +74,12 @@ def _float_parameter(level: float, maxval: float):
     """Helper function to scale a value between ``0`` and ``maxval`` and return as a float.
 
     Args:
-      level (float): Level of the operation that will be between [0, 10].
-      maxval (float): Maximum value that the operation can have. This will be scaled to
-          level/10.
+        level (float): Level of the operation that will be between [0, 10].
+        maxval (float): Maximum value that the operation can have. This will be scaled to
+            ``level/10``.
+
     Returns:
-      float: The result from scaling ``maxval`` according to ``level``.
+        float: The result from scaling ``maxval`` according to ``level``.
     """
     return float(level) * maxval / 10.
 
@@ -88,11 +90,13 @@ def _sample_level(n: float):
 
 
 def _symmetric_sample(level: float):
-    """Helper function to sample from a distribution over the domain [0.1, 10] with median == 1 and uniform probability
-    of x | 0.1 ≤ x ≤ 1, and x | 1 ≤ x ≤ 10.
+    """Helper function to sample from a symmetric distribution.
 
-    Used for sampling transforms that can range from intensity 0 to infinity, and for which an intensity of 1 == no
-    change.
+    The distribution over the domain [0.1, 10] with ``median == 1`` and uniform probability of ``x | 0.1 ≤ x ≤ 1``,
+    and ``x | 1 ≤ x ≤ 10``.
+
+    Used for sampling transforms that can range from intensity 0 to infinity and for which an intensity
+    of 1 meaning no change.
     """
     if np.random.uniform() > 0.5:
         return np.random.uniform(1, level)
@@ -106,7 +110,8 @@ def autocontrast(pil_img: Image.Image, level: float = 0.0):
     .. seealso:: :func:`PIL.ImageOps.autocontrast`.
 
     Args:
-        pil_img (Image.Image): The image
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity.
     """
     del level  # unused
     return ImageOps.autocontrast(pil_img)
@@ -118,7 +123,8 @@ def equalize(pil_img: Image.Image, level: float):
     .. seealso:: :func:`PIL.ImageOps.equalize`.
 
     Args:
-        pil_img (Image.Image): The image
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity.
     """
     del level  # unused
     return ImageOps.equalize(pil_img)
@@ -130,8 +136,9 @@ def posterize(pil_img: Image.Image, level: float):
     .. seealso:: :func:`PIL.ImageOps.posterize`.
 
     Args:
-        pil_img (Image.Image): The image
-        level (float): The intensity, which should be on ``[0, 10]``
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _int_parameter(_sample_level(level), 4)
     return ImageOps.posterize(pil_img, 4 - level)
@@ -141,8 +148,9 @@ def rotate(pil_img: Image.Image, level: float):
     """Rotate an image.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     degrees = _int_parameter(_sample_level(level), 30)
     if np.random.uniform() > 0.5:
@@ -156,8 +164,9 @@ def solarize(pil_img: Image.Image, level: float):
     .. seealso:: :func:`PIL.ImageOps.solarize`.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _int_parameter(_sample_level(level), 256)
     return ImageOps.solarize(pil_img, 256 - level)
@@ -167,8 +176,9 @@ def shear_x(pil_img: Image.Image, level: float):
     """Shear an image horizontally.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _float_parameter(_sample_level(level), 0.3)
     if np.random.uniform() > 0.5:
@@ -180,8 +190,9 @@ def shear_y(pil_img: Image.Image, level: float):
     """Shear an image vertically.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _float_parameter(_sample_level(level), 0.3)
     if np.random.uniform() > 0.5:
@@ -193,8 +204,9 @@ def translate_x(pil_img: Image.Image, level: float):
     """Shear an image horizontally.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _int_parameter(_sample_level(level), pil_img.size[0] / 3)
     if np.random.random() > 0.5:
@@ -206,8 +218,9 @@ def translate_y(pil_img: Image.Image, level: float):
     """Shear an image vertically.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _int_parameter(_sample_level(level), pil_img.size[1] / 3)
     if np.random.random() > 0.5:
@@ -230,21 +243,24 @@ def color(pil_img: Image.Image, level: float):
     .. seealso:: :class:`PIL.ImageEnhance.Color`.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _symmetric_sample(level)
     return ImageEnhance.Color(pil_img).enhance(level)
 
 
 def color_original(pil_img: Image.Image, level: float):
-    """Enhance color on an image, following the corruptions in the ImageNet-C/CIFAR10-C test sets.
+    """Enhance color on an image, following the
+    corruptions in the ImageNet-C/CIFAR10-C test sets.
 
     .. seealso :class:`PIL.ImageEnhance.Color`.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _float_parameter(_sample_level(level), 1.8) + 0.1
     return ImageEnhance.Color(pil_img).enhance(level)
@@ -256,21 +272,24 @@ def contrast(pil_img: Image.Image, level: float):
     .. seealso:: :class:`PIL.ImageEnhance.Contrast`.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _symmetric_sample(level)
     return ImageEnhance.Contrast(pil_img).enhance(level)
 
 
 def contrast_original(pil_img: Image.Image, level: float):
-    """Enhance contrast on an image, following the corruptions in the ImageNet-C/CIFAR10-C test sets.
+    """Enhance contrast on an image, following the
+    corruptions in the ImageNet-C/CIFAR10-C test sets.
 
     .. seealso:: :class:`PIL.ImageEnhance.Contrast`.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _float_parameter(_sample_level(level), 1.8) + 0.1
     return ImageEnhance.Contrast(pil_img).enhance(level)
@@ -282,8 +301,9 @@ def brightness(pil_img: Image.Image, level: float):
     .. seealso:: :class:`PIL.ImageEnhance.Brightness`.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should be
+            in ``[0, 10]``.
     """
     level = _symmetric_sample(level)
     # Reduce intensity of brightness increases
@@ -293,13 +313,15 @@ def brightness(pil_img: Image.Image, level: float):
 
 
 def brightness_original(pil_img: Image.Image, level: float):
-    """Enhance brightness on an image, following the corruptions in the ImageNet-C/CIFAR10-C test sets.
+    """Enhance brightness on an image, following the
+    corruptions in the ImageNet-C/CIFAR10-C test sets.
 
     .. seealso:: :class:`PIL.ImageEnhance.Brightness`.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _float_parameter(_sample_level(level), 1.8) + 0.1
     return ImageEnhance.Brightness(pil_img).enhance(level)
@@ -311,35 +333,38 @@ def sharpness(pil_img: Image.Image, level: float):
     .. seealso:: :class:`PIL.ImageEnhance.Sharpness`.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _symmetric_sample(level)
     return ImageEnhance.Sharpness(pil_img).enhance(level)
 
 
 def sharpness_original(pil_img: Image.Image, level: float):
-    """Enhance sharpness on an image, following the corruptions in the ImageNet-C/CIFAR10-C test sets.
+    """Enhance sharpness on an image, following the
+    corruptions in the ImageNet-C/CIFAR10-C test sets.
 
     .. seealso:: :class:`PIL.ImageEnhance.Sharpness`.
 
     Args:
-        pil_img (Image.Image): The image.
-        level (float): The intensity, which should be on ``[0, 10]``.
+        pil_img (PIL.Image.Image): The image.
+        level (float): The intensity, which should
+            be in ``[0, 10]``.
     """
     level = _float_parameter(_sample_level(level), 1.8) + 0.1
     return ImageEnhance.Sharpness(pil_img).enhance(level)
 
 
 augmentation_sets = {
-    "all": [
+    'all': [
         autocontrast, equalize, posterize, rotate, solarize, shear_x, shear_y, translate_x, translate_y, color,
         contrast, brightness, sharpness
     ],
     # Augmentations that don't overlap with ImageNet-C/CIFAR10-C test sets
-    "safe": [autocontrast, equalize, posterize, rotate, solarize, shear_x, shear_y, translate_x, translate_y],
+    'safe': [autocontrast, equalize, posterize, rotate, solarize, shear_x, shear_y, translate_x, translate_y],
     # Augmentations that use original implementations of color, contrast, brightness, and sharpness
-    "original": [
+    'original': [
         autocontrast, equalize, posterize, rotate, solarize, shear_x, shear_y, translate_x, translate_y, color_original,
         contrast_original, brightness_original, sharpness_original
     ],
