@@ -105,6 +105,16 @@ class Callback(Serializable, abc.ABC):
         del state, logger  # unused
         pass
 
+    def after_load(self, state: State, logger: Logger) -> None:
+        """Called on the :attr:`.Event.AFTER_LOAD` event.
+
+        Args:
+            state (State): The training state.
+            logger (Logger): The logger.
+        """
+        del state, logger  # unused
+        pass
+
     def fit_start(self, state: State, logger: Logger) -> None:
         """Called on the :attr:`.Event.FIT_START` event.
 
