@@ -9,12 +9,14 @@ import os
 import queue
 import sys
 import textwrap
-from typing import Any, Callable, Dict, Optional, TextIO
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, TextIO
 
-from composer.core.state import State
 from composer.loggers.logger import Logger, format_log_data_value
 from composer.loggers.logger_destination import LoggerDestination
-from composer.utils.file_helpers import FORMAT_NAME_WITH_DIST_TABLE, format_name_with_dist
+from composer.utils import FORMAT_NAME_WITH_DIST_TABLE, format_name_with_dist
+
+if TYPE_CHECKING:
+    from composer.core import State
 
 __all__ = ['FileLogger']
 
