@@ -35,6 +35,7 @@ from __future__ import annotations
 import datetime
 import logging
 import os
+import time
 from contextlib import contextmanager
 from typing import TYPE_CHECKING, Any, List, Optional, Sequence, TypeVar, Union, cast
 
@@ -454,6 +455,26 @@ def get_sampler(dataset: torch.utils.data.Dataset, *, drop_last: bool = False, s
     )
 
 
+@contextmanager
+def local_rank_zero_download_and_wait(expected_file_path: str):
+    """Context manager to wait for a file to exist on all ranks except local rank zero.
+
+    It is expected that the file will be created by local rank zero. This function is useful
+    as an alternative to ``run_local_rank_zero_first`` when downloading a file, because it does
+    not require dist to be initialized. It only requires that the ``LOCAL_RANK`` environment variable
+    is set. If dist is initialized, you should use ``run_local_rank_zero_first`` instead to avoid busy waiting.
+
+    Args:
+        expected_file_path (str): The file to wait for existence of
+    """
+    local_rank = get_local_rank()
+    if local_rank != 0:
+        while not os.path.exists(expected_file_path):
+            time.sleep(0.1)
+
+    yield
+
+
 @contextmanager
 def run_local_rank_zero_first():
     """Context manager to hold all non-zero ranks until rank zero completes.
