@@ -11,29 +11,27 @@ import pathlib
 import re
 import tempfile
 import uuid
-from typing import TYPE_CHECKING, Any, Dict, Optional, Union
+import warnings
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
+from urllib.parse import urlparse
 
 import requests
 import tqdm
 
-from composer.core.time import Timestamp
 from composer.utils import dist
 from composer.utils.iter_helpers import iterate_with_callback
-from composer.utils.object_store import ObjectStore
+from composer.utils.object_store import LibcloudObjectStore, ObjectStore, OCIObjectStore, S3ObjectStore
 
 if TYPE_CHECKING:
-    from composer.loggers import LoggerDestination
+    from composer.core import Timestamp
+    from composer.loggers import LoggerDestination, RemoteUploaderDownloader
 
 log = logging.getLogger(__name__)
 
 __all__ = [
-    'get_file',
-    'ensure_folder_is_empty',
-    'ensure_folder_has_no_conflicting_files',
-    'format_name_with_dist',
-    'format_name_with_dist_and_time',
-    'is_tar',
-    'create_symlink_file',
+    'get_file', 'ensure_folder_is_empty', 'ensure_folder_has_no_conflicting_files', 'format_name_with_dist',
+    'format_name_with_dist_and_time', 'is_tar', 'create_symlink_file', 'maybe_create_object_store_from_uri',
+    'maybe_create_remote_uploader_downloader_from_uri', 'parse_uri'
 ]
 
 
@@ -42,7 +40,7 @@ def _get_dist_config(strict: bool = True) -> Dict[str, Any]:
 
     If ``strict=True``, will error if a setting is not available (e.g. the
     environment variable is not set). Otherwise, will only return settings
-    that are availalbe.
+    that are available.
     """
     settings = {
         'rank': dist.get_global_rank,
@@ -306,6 +304,117 @@ Args:
 """
 
 
+def parse_uri(uri: str) -> Tuple[str, str, str]:
+    """Uses :py:func:`urllib.parse.urlparse` to parse the provided URI.
+
+    Args:
+        uri (str): The provided URI string
+
+    Returns:
+        Tuple[str, str, str]: A tuple containing the backend (e.g. s3), bucket name, and path.
+                              Backend and bucket name will be empty string if the input is a local path
+    """
+    parse_result = urlparse(uri)
+    backend, net_loc, path = parse_result.scheme, parse_result.netloc, parse_result.path
+    bucket_name = net_loc if '@' not in net_loc else net_loc.split('@')[0]
+    if backend == '' and bucket_name == '':
+        return backend, bucket_name, path
+    else:
+        return backend, bucket_name, path.lstrip('/')
+
+
+def maybe_create_object_store_from_uri(uri: str) -> Optional[ObjectStore]:
+    """Automatically creates an :class:`composer.utils.ObjectStore` from supported URI formats.
+
+    Currently supported backends are ``s3://``, ``oci://``, and local paths (in which case ``None`` will be returned)
+
+    Args:
+        uri (str): The path to (maybe) create an :class:`composer.utils.ObjectStore` from
+
+    Raises:
+        NotImplementedError: Raises when the URI format is not supported.
+
+    Returns:
+        Optional[ObjectStore]: Returns an :class:`composer.utils.ObjectStore` if the URI is of a supported format, otherwise None
+    """
+    backend, bucket_name, _ = parse_uri(uri)
+    if backend == '':
+        return None
+    if backend == 's3':
+        return S3ObjectStore(bucket=bucket_name)
+    elif backend == 'wandb':
+        raise NotImplementedError(f'There is no implementation for WandB load_object_store via URI. Please use '
+                                  'WandBLogger')
+    elif backend == 'gs':
+        if 'GCS_KEY' not in os.environ or 'GCS_SECRET' not in os.environ:
+            raise ValueError(
+                'You must set the GCS_KEY and GCS_SECRET env variable with you HMAC access id and secret respectively')
+
+        return LibcloudObjectStore(
+            provider='google_storage',
+            container=bucket_name,
+            key_environ='GCS_KEY',  # Name of env variable for HMAC access id.
+            secret_environ='GCS_SECRET',  # Name of env variable for HMAC secret.
+        )
+    elif backend == 'oci':
+        return OCIObjectStore(bucket=bucket_name)
+    else:
+        raise NotImplementedError(f'There is no implementation for the cloud backend {backend} via URI. Please use '
+                                  's3 or one of the supported object stores')
+
+
+def maybe_create_remote_uploader_downloader_from_uri(
+        uri: str, loggers: List[LoggerDestination]) -> Optional['RemoteUploaderDownloader']:
+    """Automatically creates a :class:`composer.loggers.RemoteUploaderDownloader` from supported URI formats.
+
+    Currently supported backends are ``s3://``, ``oci://``, and local paths (in which case ``None`` will be returned)
+
+    Args:
+        uri (str):The path to (maybe) create a :class:`composer.loggers.RemoteUploaderDownloader` from
+        loggers (List[:class:`composer.loggers.LoggerDestination`]): List of the existing :class:`composer.loggers.LoggerDestination` s so as to not create a duplicate
+
+    Raises:
+        NotImplementedError: Raises when the URI format is not supported.
+
+    Returns:
+        Optional[RemoteUploaderDownloader]: Returns a :class:`composer.loggers.RemoteUploaderDownloader` if the URI is of a supported format, otherwise None
+    """
+    from composer.loggers import RemoteUploaderDownloader
+    existing_remote_uds = [logger_dest for logger_dest in loggers if isinstance(logger_dest, RemoteUploaderDownloader)]
+    backend, bucket_name, _ = parse_uri(uri)
+    if backend == '':
+        return None
+    for existing_remote_ud in existing_remote_uds:
+        if ((existing_remote_ud.remote_backend_name == backend) and
+            (existing_remote_ud.remote_bucket_name == bucket_name)):
+            warnings.warn(
+                f'There already exists a RemoteUploaderDownloader object to handle the uri: {uri} you specified')
+            return None
+    if backend in ['s3', 'oci']:
+        return RemoteUploaderDownloader(bucket_uri=f'{backend}://{bucket_name}')
+
+    elif backend == 'gs':
+        if 'GCS_KEY' not in os.environ or 'GCS_SECRET' not in os.environ:
+            raise ValueError(
+                'You must set the GCS_KEY and GCS_SECRET env variable with you HMAC access id and secret respectively')
+        return RemoteUploaderDownloader(
+            bucket_uri=f'libcloud://{bucket_name}',
+            backend_kwargs={
+                'provider': 'google_storage',
+                'container': bucket_name,
+                'key_environ': 'GCS_KEY',  # Name of env variable for HMAC access id.
+                'secret_environ': 'GCS_SECRET',  # Name of env variable for HMAC secret.
+            })
+
+    elif backend == 'wandb':
+        raise NotImplementedError(f'There is no implementation for WandB via URI. Please use '
+                                  'WandBLogger with log_artifacts set to True')
+
+    else:
+        raise NotImplementedError(f'There is no implementation for the cloud backend {backend} via URI. Please use '
+                                  's3 or one of the supported RemoteUploaderDownloader object stores')
+
+
 def get_file(
     path: str,
     destination: str,
@@ -324,6 +433,10 @@ def get_file(
             *   If ``object_store`` is not specified but the ``path`` begins with ``http://`` or ``https://``,
                 the object at this URL will be downloaded.
 
+            *   If ``object_store`` is not specified, but the ``path`` begins with ``s3://``, or another backend
+                supported by :meth:`composer.utils.maybe_create_object_store_from_uri` an appropriate object store
+                will be created and used.
+
             *   Otherwise, ``path`` is presumed to be a local filepath.
 
         destination (str): The destination filepath.
@@ -347,6 +460,10 @@ def get_file(
     Raises:
         FileNotFoundError: If the ``path`` does not exist.
     """
+    if object_store is None and not (path.lower().startswith('http://') or path.lower().startswith('https://')):
+        object_store = maybe_create_object_store_from_uri(path)
+        _, _, path = parse_uri(path)
+
     if path.endswith('.symlink'):
         with tempfile.TemporaryDirectory() as tmpdir:
             symlink_file_name = os.path.join(tmpdir, 'file.symlink')
